@@ -1,4 +1,4 @@
-# $Id: nobs.R 1551 2012-06-06 22:09:04Z warnes $
+# $Id: nobs.R 1564 2012-06-13 01:10:28Z warnes $
 
 ## Redefine here, so that the locally defined methods (particularly
 ## nobs.default) take precidence over the ones now defined in the
@@ -8,7 +8,7 @@ nobs <- function(object, ...)
 
 nobs.default <- function(object, ...)
   {
-    if(is.numeric(object))
+    if(is.numeric(object) || is.logical(object))
       sum( !is.na(object) )
     else
       stats:::nobs.default(object, ...)
@@ -21,4 +21,3 @@ nobs.data.frame <- function(object, ...)
 ## Now provided by 'stats' package, so provide alias to satisfy
 ## dependencies
 nobs.lm <- stats:::nobs.lm
-
